Export Package VRC : bcB40Mc4cn24
Update compared VRC:   B40 c4cn24
Only Package       : Yes
Based on sessions  : No
Script sources     : No
Function  sources  : No
Library sources    : No
---------------------------------------
C = Charts
q = Questions
c = Messages
l = Labels
d = Domains
t = Table Definitions
s = Sessions
p = Scripts
o = Objects
f = Forms
F = Form Dumps
m = Menus
M = Menu Dumps
r = Reports
i = Impl. Functions
b = Functions
h = Help Text Codes
----------------------
dbcckon                             B40Mc4cn24
dbcdsca                             B40Mc4cn24
dbcreje                             B40Mc4cn24
pbcrun0000                          B40Mc4cn24 (without source)
pbcrun9087                          B40Mc4cn24 (without source)
pbcrundll0000                       B40Mc4cn24 (without source)
mbcgctconvert 12                    B40Mc4cn24
obcrun0000                          B40Mc4cn24
obcrun9087                          B40Mc4cn24
obcrundll0000                       B40Mc4cn24
obcsql3272                          B40Mc4cn24
Mbcgctconvert 12                    B40Mc4cn24
